Hi Thanks for your comment. I uploaded a couple of tests using `hyperfine` to show cases where it might be faster. Will put in more work to do a proper benchmarking session in the days to come.
What makes it circumstantially more performant, by the way?
Off-topic, but consider changing "circumstancially" to "circumstantially" in the README; the latter is the correct term.
The thread above might help provide the start of an answer.
> Off-topic, but consider changing "circumstancially" to "circumstantially" in the README; the latter is the correct term.
Done, thanks for spotting the typo.